==> platform-4.9.1-sources.jar: com/gtis/plat/service/impl/SysStuffServiceImpl.java <==
package com.gtis.plat.service.impl;

import java.util.HashMap;
import java.util.List;

import com.gtis.plat.dao.SysStuffDao;
import com.gtis.plat.service.SysStuffService;

public class SysStuffServiceImpl implements SysStuffService{
	private SysStuffDao stuffDao;

	public List<HashMap<String,String>> getStuffConfig() {
		return stuffDao.getStuffConfig();
	}

	public List<HashMap<String,String>> getStuffConfigByProId(String proId) {
		return stuffDao.getStuffConfigByProId(proId);
	}
	
	public List<HashMap<String, String>> getFileByStuffId(String stuffId) {
//		return stuffDao.getFileByStuffId(stuffId);
        return null;
	}
	
	public HashMap<String, String> getFileById(String fileId) {
//		return stuffDao.getFileById(fileId);
        return null;
	}
	
	public void deleteFileById(String stuffId) {
//		stuffDao.deleteFileById(stuffId);
	}
	
	public boolean insertStuffFile(HashMap stuffFile) {
//		return stuffDao.insertStuffFile(stuffFile);
        return false;
	}
	
	public boolean updateStuffFile(HashMap stuffFile) {
//		return stuffDao.updateStuffFile(stuffFile);
        return false;
	}
	
	public SysStuffDao getStuffDao() {
		return stuffDao;
	}

	public void setStuffDao(SysStuffDao stuffDao) {
		this.stuffDao = stuffDao;
	}

	public HashMap<String, byte[]> getFileContentById(String fileId) {
//		return stuffDao.getFileContentById(fileId);
        return null;
	}

	public List<HashMap<String, String>> getFileByStuffIdProId(HashMap map) {
//		return stuffDao.getFileByStuffIdProId(map);
        return null;
	}

	public boolean insertStuffConfig(HashMap stuffConfig) {
		return stuffDao.insertStuffConfig(stuffConfig);
	}

	public void deleteConfigById(String stuffId) {
		stuffDao.deleteConfigById(stuffId);
	}

	public void deleteConfigByProId(String proId) {
		stuffDao.deleteConfigByProId(proId);
	}

	public List<String> getStuffIdByProId(String proId) {
		return stuffDao.getStuffIdByProId(proId);
	}

	public List<String> getFileIdByProId(String proId) {
//		return stuffDao.getFileIdByProId(proId);
        return null;
	}
	
	//<!-- 获取StuffId -->
	public String getStuffIdbyWorkflowDefinitionIdAndStuffName(String workflowDefinitionId, String stuffName){
		return stuffDao.getStuffIdbyWorkflowDefinitionIdAndStuffName(workflowDefinitionId, stuffName);
	}
	
	//<!-- 根据ProId与StuffId获取附件List -->
	public List<HashMap<String, String>> getStuffFileByProIdAndStuffId(String proid, String stuffId){
//		return stuffDao.getStuffFileByProIdAndStuffId(proid, stuffId);
        return null;
	}

	public HashMap<String, String> getStuffConfigByStuffId(String stuffConfigId) {
		return stuffDao.getStuffConfigByStuffId(stuffConfigId);
	}
	
}

==> platform-4.9.13-sources.jar: com/gtis/plat/service/impl/SysStuffServiceImpl.java <==
package com.gtis.plat.service.impl;

import java.util.HashMap;
import java.util.List;

import com.gtis.plat.dao.SysStuffDao;
import com.gtis.plat.service.SysStuffService;

public class SysStuffServiceImpl implements SysStuffService{
	private SysStuffDao stuffDao;

	public List<HashMap<String,String>> getStuffConfig() {
		return stuffDao.getStuffConfig();
	}

	public List<HashMap<String,String>> getStuffConfigByProId(String proId) {
		return stuffDao.getStuffConfigByProId(proId);
	}
	
	public List<HashMap<String, String>> getFileByStuffId(String stuffId) {
//		return stuffDao.getFileByStuffId(stuffId);
        return null;
	}
	
	public HashMap<String, String> getFileById(String fileId) {
//		return stuffDao.getFileById(fileId);
        return null;
	}
	
	public void deleteFileById(String stuffId) {
//		stuffDao.deleteFileById(stuffId);
	}
	
	public boolean insertStuffFile(HashMap stuffFile) {
//		return stuffDao.insertStuffFile(stuffFile);
        return false;
	}
	
	public boolean updateStuffFile(HashMap stuffFile) {
//		return stuffDao.updateStuffFile(stuffFile);
        return false;
	}
	
	public SysStuffDao getStuffDao() {
		return stuffDao;
	}

	public void setStuffDao(SysStuffDao stuffDao) {
		this.stuffDao = stuffDao;
	}

	public HashMap<String, byte[]> getFileContentById(String fileId) {
//		return stuffDao.getFileContentById(fileId);
        return null;
	}

	/**
	 * 根据参数获取附件定义列表
	 * @param map
	 * @return
	 */
	public List<HashMap<String, String>> getFileByStuffIdProId(HashMap map) {
		return stuffDao.getStuffConfigByParam(map);
	}

	public boolean insertStuffConfig(HashMap stuffConfig) {
		return stuffDao.insertStuffConfig(stuffConfig);
	}

	public void deleteConfigById(String stuffId) {
		stuffDao.deleteConfigById(stuffId);
	}

	public void deleteConfigByProId(String proId) {
		stuffDao.deleteConfigByProId(proId);
	}

	public List<String> getStuffIdByProId(String proId) {
		return stuffDao.getStuffIdByProId(proId);
	}

	public List<String> getFileIdByProId(String proId) {
//		return stuffDao.getFileIdByProId(proId);
        return null;
	}
	
	//<!-- 获取StuffId -->
	public String getStuffIdbyWorkflowDefinitionIdAndStuffName(String workflowDefinitionId, String stuffName){
		return stuffDao.getStuffIdbyWorkflowDefinitionIdAndStuffName(workflowDefinitionId, stuffName);
	}
	
	//<!-- 根据ProId与StuffId获取附件List -->
	public List<HashMap<String, String>> getStuffFileByProIdAndStuffId(String proid, String stuffId){
//		return stuffDao.getStuffFileByProIdAndStuffId(proid, stuffId);
        return null;
	}

	public HashMap<String, String> getStuffConfigByStuffId(String stuffConfigId) {
		return stuffDao.getStuffConfigByStuffId(stuffConfigId);
	}
	
}
